@@ -94,6 +94,80 @@ static cpl_error_code ADDTYPE(cpl_filter_median_slow)(void *, cpl_binary **,
                                                       cpl_size, cpl_size,
                                                       cpl_border_mode);
 
+#ifndef CPL_MEDIAN_SAMPLE
+static void
+ADDTYPE(cpl_filter_median_even)(void *, const void *,
+                                cpl_size, cpl_size,
+                                cpl_size, cpl_size) CPL_ATTR_NONNULL;
+
+/*----------------------------------------------------------------------------*/
+/**
+   @internal
+   @ingroup cpl_image
+   @brief  Median filter border positions with even samples and no bpm
+   @param  vout   The pixel buffer to hold the filtered result
+   @param  vin    The input pixel buffer to be filtered
+   @param  nx    image width
+   @param  ny    image height
+   @param  rx    filtering half-size in x
+   @param  ry    filtering half-size in y
+   @return void
+   @note This function must be called after a fast-filtering (i.e. full-kernel
+         and no bad pixels) with border mode set to filter, in order to
+         refilter the positions that have an even number of samples
+
+   For a position on the left or right side of the image, where an odd number
+   of columns of the filtering kernel is outside the input buffer, there is
+   an even number of samples.
+
+   For a position on the top or bottom part of the image, where an odd number
+   of rows of the filtering kernel is outside the input buffer, there is
+   an even number of samples.
+
+   In the four corners of the image, there is an even number of samples, if
+   one or both of the above is true.
+   
+*/
+/*----------------------------------------------------------------------------*/
+static void ADDTYPE(cpl_filter_median_even)(void * vout, const void * vin,
+                                            cpl_size nx, cpl_size ny,
+                                            cpl_size rx, cpl_size ry)
+{
+
+    OUT_TYPE * out = (OUT_TYPE*)vout;
+    const IN_TYPE  * in  = (const IN_TYPE*)vin;
+    IN_TYPE window[(2 * rx + 1) * (2 * ry + 1)];
+    cpl_size     x, y;
+
+
+    /* FIXME: Create 4 shorter loops... ? */
+    for (y = 0; y < ny; y++) {
+        const size_t y_1 = CX_MAX(0,    y - ry);
+        const size_t y2  = CX_MIN(ny-1, y + ry);
+        for (x = 0; x < nx; x++) {
+            const size_t     x1 = CX_MAX(0,    x - rx);
+            const size_t     x2 = CX_MIN(nx-1, x + rx);
+
+            if (((2 * ry - (y2 - y_1)) & 1) != 0 ||
+                ((2 * rx - (x2 - x1 )) & 1) != 0) {
+                /* The pixel position has an even number of samples */
+
+                const IN_TYPE * inj = in + y_1 * nx;
+                size_t j, k = 0;
+
+                for (j = y_1; j < 1 + y2; j++, inj += nx, k += 1 + x2 - x1) {
+                    (void)memcpy(window + k, inj + x1,
+                                 (1 + x2 - x1) * sizeof(IN_TYPE));
+                }
+                assert( k % 2 == 0);
+
+                out[x + y * nx] = ADDTYPE(cpl_tools_get_median)(window, k);
+            }
+        }
+    }
+}
+#endif
+
 /*----------------------------------------------------------------------------*/
 /**
    @internal
