@@ -1,4 +1,4 @@
-/* $Id: cpl_msg.c,v 1.58 2013/02/08 09:48:02 rpalsa Exp $
+/* $Id: cpl_msg.c,v 1.58 2013-02-08 09:48:02 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2013/02/08 09:48:02 $
+ * $Date: 2013-02-08 09:48:02 $
  * $Revision: 1.58 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 
@@ -297,7 +297,7 @@ static void _cpl_change_width(int i)
 
     struct winsize win;
 
-    i = 0;  /* To avoid compiler warning */
+    (void) i;  /* To avoid compiler warning */
 
     if (ioctl(out_stream, TIOCGWINSZ, &win) < 0 || win.ws_col < 1)
         page_width = DEFAULT_WIDTH;
@@ -545,20 +545,28 @@ inline static void cpl_msg_out(cpl_msg_severity severity,
     */
 
     if (severity == CPL_MSG_ERROR) {
-        strcat(msg_log, ERROR_STRING);
-        strcat(msg_term, ERROR_STRING);
+        strncat(msg_log, ERROR_STRING,
+                CPL_MAX_MSG_LENGTH - strlen(msg_log) - 1);
+        strncat(msg_term, ERROR_STRING,
+               CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
     }
     else if (severity == CPL_MSG_WARNING) {
-        strcat(msg_log, WARNING_STRING);
-        strcat(msg_term, WARNING_STRING);
+        strncat(msg_log, WARNING_STRING,
+               CPL_MAX_MSG_LENGTH - strlen(msg_log) - 1);
+        strncat(msg_term, WARNING_STRING,
+               CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
     }
     else if (severity == CPL_MSG_INFO) {
-        strcat(msg_log, INFO_STRING);
-        strcat(msg_term, INFO_STRING);
+        strncat(msg_log, INFO_STRING,
+               CPL_MAX_MSG_LENGTH - strlen(msg_log) - 1);
+        strncat(msg_term, INFO_STRING,
+               CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
     }
     else if (severity == CPL_MSG_DEBUG) {
-        strcat(msg_log, DEBUG_STRING);
-        strcat(msg_term, DEBUG_STRING);
+        strncat(msg_log, DEBUG_STRING,
+               CPL_MAX_MSG_LENGTH - strlen(msg_log) - 1);
+        strncat(msg_term, DEBUG_STRING,
+               CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
     }
 
 
@@ -567,17 +575,17 @@ inline static void cpl_msg_out(cpl_msg_severity severity,
     */
 
     if (domain_tag) {
-        strcat(msg_term, domain);
-        strcat(msg_term, ": ");
+        strncat(msg_term, domain, CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
+        strncat(msg_term, ": ", CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
     }
 
     if (component_tag || term_min_level == CPL_MSG_DEBUG) {
-        strcat(msg_term, component);
-        strcat(msg_term, ": ");
+        strncat(msg_term, component, CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
+        strncat(msg_term, ": ", CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
     }
 
-    strcat(msg_log, component);
-    strcat(msg_log, ": ");
+    strncat(msg_log, component, CPL_MAX_MSG_LENGTH - strlen(msg_log) - 1);
+    strncat(msg_log, ": ", CPL_MAX_MSG_LENGTH - strlen(msg_log) - 1);
 
 
 #ifdef _OPENMP
@@ -587,9 +595,9 @@ inline static void cpl_msg_out(cpl_msg_severity severity,
     */
 
    tid = cpl_sprintf("[tid=%03d] ", omp_get_thread_num());
-   strcat(msg_log, tid);
+   strncat(msg_log, tid, CPL_MAX_MSG_LENGTH - strlen(msg_log) - 1);
    if (threadid_tag)
-       strcat(msg_term, tid);
+       strncat(msg_term, tid, CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
    cpl_free(tid);
 
 #endif
@@ -599,8 +607,8 @@ inline static void cpl_msg_out(cpl_msg_severity severity,
     */
 
     for (i = 0; i < indent_value; i++) {
-        strcat(msg_log, " ");
-        strcat(msg_term, " ");
+        strncat(msg_log, " ", CPL_MAX_MSG_LENGTH - strlen(msg_log) - 1);
+        strncat(msg_term, " ", CPL_MAX_MSG_LENGTH - strlen(msg_term) - 1);
     }
 
 
