@@ -1,4 +1,4 @@
-/* $Id: cpl_test.h,v 1.62 2013/02/20 09:47:08 llundin Exp $
+/* $Id: cpl_test.h,v 1.63 2013-04-04 13:10:32 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2013/02/20 09:47:08 $
- * $Revision: 1.62 $
- * $Name: cpl-6_3_1 $
+ * $Date: 2013-04-04 13:10:32 $
+ * $Revision: 1.63 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifndef CPL_TEST_H
@@ -794,6 +794,37 @@ CPL_BEGIN_DECLS
     } while (0)
 
 
+/*----------------------------------------------------------------------------*/
+/**
+  @hideinitializer
+  @ingroup cpl_test
+  @brief  Test if two images are identical within a given (relative) tolerance
+  @param  first       The first image in the comparison
+  @param  second      The second image of identical size in the comparison
+  @param  tolerance   A non-negative tolerance
+  @return void
+  @see cpl_test_rel()
+  @note The test will fail if one or both the images are NULL
+
+  For each pixel position the two values x, y must pass the test:
+  |x - y| <= tol * min(|x|, |y|).
+  This definition is chosen since it is commutative and meaningful also for
+  zero-valued pixels.
+
+ */
+/*----------------------------------------------------------------------------*/
+#define cpl_test_image_rel(first, second, tolerance) do {               \
+        const int cpl_test_errno = errno;                               \
+        const cpl_flops cpl_test_flops = cpl_test_get_flops();          \
+        const double cpl_test_time = cpl_test_get_walltime();           \
+        cpl_errorstate cpl_test_state = cpl_errorstate_get();           \
+        cpl_test_image_rel_macro(cpl_test_errno, cpl_test_time,         \
+                                 cpl_test_flops, cpl_test_state, first, \
+                                 #first,  second, #second, tolerance,   \
+                                 #tolerance,  cpl_func, __FILE__, __LINE__); \
+    } while (0)
+
+
 /*----------------------------------------------------------------------------*/
 /**
   @hideinitializer
@@ -859,7 +890,7 @@ CPL_BEGIN_DECLS
   @param second    The second value in the comparison, side-effects are allowed
   @param tolerance A non-negative tolerance
   @note  If the tolerance is negative or if one but not both of the two values
-         is zero, the test will always fail. if both values are zero, the test
+         is zero, the test will always fail. If both values are zero, the test
          will succeed for any non-negative tolerance. The test is commutative
          in the two values.
   @see   cpl_test()
@@ -1076,8 +1107,8 @@ void cpl_test_abs_macro(int, double, cpl_flops, cpl_errorstate, double,
 
 #ifdef _Complex_I
 void cpl_test_abs_complex_macro(int, double, cpl_flops, cpl_errorstate, 
-                                double complex, const char *, 
-                                double complex, const char *, double,
+                                _Complex double, const char *, 
+                                _Complex double, const char *, double,
                                 const char *, const char *, const char *,
                                 unsigned) CPL_ATTR_NONNULL;
 #endif
@@ -1127,6 +1158,16 @@ void cpl_test_image_abs_macro(int, double, cpl_flops, cpl_errorstate,
 #endif
     ;
 
+void cpl_test_image_rel_macro(int, double, cpl_flops, cpl_errorstate,
+                              const cpl_image *, const char *,
+                              const cpl_image *, const char *, double,
+                              const char *, const char *, const char *,
+                              unsigned)
+#ifdef CPL_HAVE_ATTR_NONNULL
+    __attribute__((nonnull(6, 8, 10, 11, 12)))
+#endif
+    ;
+
 void cpl_test_imagelist_abs_macro(int, double, cpl_flops, cpl_errorstate,
                                   const cpl_imagelist *,
                                   const char *,
