@@ -35,10 +35,8 @@ TYPE_ADD(filter_median_bf)(const PIXEL_TYPE *in, PIXEL_TYPE *out,
 {
     PIXEL_TYPE *data = cpl_malloc((size_t)(2*Rx+1) * (size_t)(2*Ry+1)
                                   * sizeof(*data));
-    unsigned y;
-
     if (mode == CPL_BORDER_FILTER) {
-        
+#ifdef CPL_MEDIAN_SAMPLE
         const unsigned Nx_larger = Nx + 2*Rx;
         const unsigned Ny_larger = Ny + 2*Ry;
 
@@ -48,15 +46,42 @@ TYPE_ADD(filter_median_bf)(const PIXEL_TYPE *in, PIXEL_TYPE *out,
 
         TYPE_ADD(cpl_image_filter_fill_chess)(in_larger, in, Nx_larger,
                                               Ny_larger, Nx, Ny, Rx, Ry);
-        
+
         TYPE_ADD(filter_median_bf)(in_larger, out,
                                    Nx_larger, Ny_larger,
                                    Rx, Ry,
                                    CPL_BORDER_CROP);
 
         cpl_free(in_larger);
+#else
+        cpl_size y;
+        for (y = 0; y < Ny; y++) {
+            const size_t y_1 = CX_MAX(0,    y - Ry);
+            const size_t y2  = CX_MIN(Ny-1, y + Ry);
+            cpl_size x;
+            for (x = 0; x < Nx; x++) {
+                const size_t     x1 = CX_MAX(0,    x - Rx);
+                const size_t     x2 = CX_MIN(Nx-1, x + Rx);
 
+
+                const PIXEL_TYPE    * inj  = in + y_1 * Nx;
+                size_t k = 0;
+                size_t i, j;
+
+                for (j = y_1; j < 1 + y2; j++, inj += Nx) {
+                    /* FIXME: use memcpy() */
+                    for (i = x1; i < 1 + x2; i++) {
+                        data[k++] = inj[i];
+                    }
+                }
+                assert( k <= (size_t)(2*Rx+1) * (size_t)(2*Ry+1));
+
+                out[x + y * Nx] = TYPE_ADD(cpl_tools_get_median)(data, k);
+            }
+        }
+#endif
     } else {
+        unsigned y;
         if (mode == CPL_BORDER_CROP) {
             out += Rx;
         } else {
