@@ -60,6 +60,7 @@
 
 #define DATAMD5                     "DATAMD5"
 #define PIPEFILE                    "PIPEFILE"
+#define CHECKSUM                    "CHECKSUM"
 #define PRO_DID                     "ESO PRO DID"
 #define DPR_CATG                    "ESO DPR CATG"
 #define PRO_CATG                    CPL_DFS_PRO_CATG 
@@ -1309,6 +1310,7 @@ static cpl_error_code cpl_dfs_update_product_header_(cpl_frameset * self)
                     if (!md5sum) {
                         code = cpl_error_set_where_();
                     } else {
+                        const char* inclist = CHECKSUM;
 
                         if (fits_update_key_str(fproduct, DATAMD5, md5sum,
                                                 "MD5 checksum", &error)) {
@@ -1329,6 +1331,30 @@ static cpl_error_code cpl_dfs_update_product_header_(cpl_frameset * self)
                             error = 0;
                         }
                         cpl_free(md5sum);
+
+                        /* Check if FITS standard CHECKSUM was present in the
+                         * primary header we just modified. If it was then we
+                         * must also update that checksum. */
+                        if (! fits_find_nextkey(fproduct, (char **)&inclist, 1,
+                                                NULL, 0, card, &error)) {
+
+                            if (fits_write_chksum(fproduct, &error)) {
+                                code = cpl_error_set_fits(CPL_ERROR_FILE_IO,
+                                                        error,
+                                                        fits_update_key_str,
+                                                        "filename='%s', key='"
+                                                        CHECKSUM "'", filename);
+                                error = 0;
+                            }
+                        } else if (error == KEY_NO_EXIST) {
+                            error = 0; /* Reset error if key not found */
+                        } else {
+                            code = cpl_error_set_fits(CPL_ERROR_FILE_IO, error,
+                                                      fits_update_key_str,
+                                                      "filename='%s', key='"
+                                                      CHECKSUM "'", filename);
+                            error = 0;
+                        }
                     }
                 }
 
