@@ -1,4 +1,4 @@
-/* $Id: cxdeque.c,v 1.13 2012/12/18 16:05:45 rpalsa Exp $
+/* $Id: cxdeque.c,v 1.13 2012-12-18 16:05:45 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/12/18 16:05:45 $
+ * $Date: 2012-12-18 16:05:45 $
  * $Revision: 1.13 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -444,7 +444,7 @@ _cx_deque_put(cx_deque *deque, cxsize position, cxptr data)
 inline static cx_deque_iterator
 _cx_deque_begin(const cx_deque *deque)
 {
-    deque = NULL;   /* To avoid a compiler warning */
+    (void) deque;   /* To avoid a compiler warning */
     return 0;
 }
 
@@ -925,6 +925,7 @@ cxsize
 cx_deque_max_size(const cx_deque *deque)
 {
 
+    (void) deque;  /* Prevent warnings if cx_assert is disabled. */
     cx_assert(deque != NULL);
     return (cxsize)(-1);
 
