@@ -1,4 +1,4 @@
-/* $Id: cxtree.c,v 1.10 2012/12/10 14:36:49 rpalsa Exp $
+/* $Id: cxtree.c,v 1.10 2012-12-10 14:36:49 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/12/10 14:36:49 $
+ * $Date: 2012-12-10 14:36:49 $
  * $Revision: 1.10 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1307,6 +1307,7 @@ cxsize
 cx_tree_max_size(const cx_tree *tree)
 {
 
+    (void) tree;  /* Prevent warnings if cx_assert is disabled. */
     cx_assert(tree != NULL);
 
     return (cxsize)(-1);
@@ -1414,6 +1415,7 @@ cx_tree_assign(cx_tree *tree, cx_tree_iterator position, cxcptr data)
     cxptr tmp;
 
 
+    (void) tree;  /* Prevent warnings if cx_assert is disabled. */
     cx_assert(tree != NULL);
     cx_assert(position != NULL);
     cx_assert(_cx_tree_exists(tree, position));
@@ -1447,6 +1449,7 @@ cxptr
 cx_tree_get_key(const cx_tree *tree, cx_tree_const_iterator position)
 {
 
+    (void) tree;  /* Prevent warnings if cx_assert is disabled. */
     cx_assert(tree != NULL);
     cx_assert(position != NULL);
     cx_assert(_cx_tree_exists(tree, (cx_tree_iterator)position));
@@ -1473,6 +1476,7 @@ cxptr
 cx_tree_get_value(const cx_tree *tree, cx_tree_const_iterator position)
 {
 
+    (void) tree;  /* Prevent warnings if cx_assert is disabled. */
     cx_assert(tree != NULL);
     cx_assert(position != NULL);
     cx_assert(_cx_tree_exists(tree, (cx_tree_iterator)position));
